{
  inputs = {
    nixpkgs.url = "github:NixOS/nixpkgs/nixos-22.11";
    nixos-unstable.url = "github:NixOS/nixpkgs/master";
    home-manager = {
      url = "github:nix-community/home-manager/release-22.11";
      inputs.nixpkgs.follows = "nixpkgs";
    };
  };

  outputs =
    inputs@{ self, nixpkgs, nixos-unstable, home-manager }:
    let
      sysLinuxX86 = "x86_64-linux";
      sysDarwinAarch = "aarch64-darwin";
      sysLinuxAarch = "aarch-linux";

      wrapPkgsSystem = { system }:
        import nixpkgs rec {
          inherit system;
          unstable = wrapUnstablePkgsSystem { inherit system; };
          config.allowUnfree = true;
          overlays = [
            (final: prev: { inherit unstable; })
          ];
        };

      wrapUnstablePkgsSystem = { system }:
        import nixos-unstable {
          inherit system;
          config.allowUnfree = true;
        };

      pkgsLinuxX64 = wrapPkgsSystem { system = sysLinuxX86; };
      unstableLinuxX64 = wrapUnstablePkgsSystem { system = sysLinuxX86; };
      utilsLinuxX64 = import ./lib {
        inherit nixpkgs nixos-unstable home-manager;
        pkgs = pkgsLinuxX64;
        unstable = unstableLinuxX64;
        system = sysLinuxX86;
      };

      pkgsLinuxAarch = wrapPkgsSystem { system = sysLinuxAarch; };
      unstableLinuxAarch = wrapUnstablePkgsSystem { system = sysLinuxAarch; };
      utilsLinuxAarch = import ./lib {
        inherit nixpkgs nixos-unstable home-manager;
        pkgs = pkgsLinuxAarch;
        unstable = unstableLinuxAarch;
        system = sysLinuxAarch;
      };

      pkgsDarwin = wrapPkgsSystem { system = sysDarwinAarch; };
      unstableDarwin = wrapUnstablePkgsSystem { system = sysDarwinAarch; };
      utilsDarwin = import ./lib {
        inherit nixpkgs nixos-unstable home-manager;
        pkgs = pkgsDarwin;
        unstable = unstableDarwin;
        system = sysDarwinAarch;
      };
    in
    {
      nixosConfigurations = {
        architect = utilsLinuxX64.host.mkHost {
          name = "architect";
          users = [{
            user = "giulio";
            roles = [ ];
          }];
        };
        gAluminum = utilsLinuxX64.host.mkHost {
          name = "gAluminum";
          users = [{
            user = "giulio";
            roles = [ "desktop" "ssh" "git" ];
          }];
          roles = [ "gnome" ];
        };
      };
      homeConfigurations = {
        giulioMac = utilsDarwin.user.mkHMUser {
          name = "giulio";
          roles = [ "ssh" ];
        };
        giulioAarch = utilsAarch.user.mkHMUser {
          name = "giulio";
          roles = [ "ssh" ];
        };
      };
    };
}
